summaryrefslogtreecommitdiffstats
path: root/kttsd/filters/talkerchooser/talkerchooserconf.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:28:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:28:14 -0600
commit6379d18e0ec321e0e08a1389ee4a12f0eaa5992e (patch)
treedd3e6f3b6c190bc5ea47516ddbe04c6777fa6a04 /kttsd/filters/talkerchooser/talkerchooserconf.cpp
parent0b54abbdf80cef08e5cb8ef7b8b7af31c54dd9b4 (diff)
downloadtdeaccessibility-6379d18e0ec321e0e08a1389ee4a12f0eaa5992e.tar.gz
tdeaccessibility-6379d18e0ec321e0e08a1389ee4a12f0eaa5992e.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kttsd/filters/talkerchooser/talkerchooserconf.cpp')
-rw-r--r--kttsd/filters/talkerchooser/talkerchooserconf.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kttsd/filters/talkerchooser/talkerchooserconf.cpp b/kttsd/filters/talkerchooser/talkerchooserconf.cpp
index f62e185..ce5e00f 100644
--- a/kttsd/filters/talkerchooser/talkerchooserconf.cpp
+++ b/kttsd/filters/talkerchooser/talkerchooserconf.cpp
@@ -103,11 +103,11 @@ TalkerChooserConf::~TalkerChooserConf(){
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*/
-void TalkerChooserConf::load(KConfig* config, const TQString& configGroup){
+void TalkerChooserConf::load(TDEConfig* config, const TQString& configGroup){
// kdDebug() << "TalkerChooserConf::load: Running" << endl;
config->setGroup( configGroup );
m_widget->nameLineEdit->setText( config->readEntry( "UserFilterName", m_widget->nameLineEdit->text() ) );
@@ -138,11 +138,11 @@ void TalkerChooserConf::load(KConfig* config, const TQString& configGroup){
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
-void TalkerChooserConf::save(KConfig* config, const TQString& configGroup){
+void TalkerChooserConf::save(TDEConfig* config, const TQString& configGroup){
// kdDebug() << "TalkerChooserConf::save: Running" << endl;
config->setGroup( configGroup );
config->writeEntry( "UserFilterName", m_widget->nameLineEdit->text() );
@@ -239,7 +239,7 @@ void TalkerChooserConf::slotLoadButton_clicked()
m_widget,
"talkerchooser_loadfile");
if ( filename.isEmpty() ) return;
- KConfig* cfg = new KConfig( filename, true, false, 0 );
+ TDEConfig* cfg = new TDEConfig( filename, true, false, 0 );
load( cfg, "Filter" );
delete cfg;
configChanged();
@@ -253,7 +253,7 @@ void TalkerChooserConf::slotSaveButton_clicked()
m_widget,
"talkerchooser_savefile");
if ( filename.isEmpty() ) return;
- KConfig* cfg = new KConfig( filename, false, false, 0 );
+ TDEConfig* cfg = new TDEConfig( filename, false, false, 0 );
save( cfg, "Filter" );
delete cfg;
}
@@ -103,11 +103,11 @@ TalkerChooserConf::~TalkerChooserConf(){
* The plugin should read its configuration from the specified group
* in the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -138,11 +138,11 @@ void TalkerChooserConf::load(KConfig* config, const TQString& configGroup){
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.